@@ -675,7 +675,7 @@ class BaseRester(Generic[T]):
             Tuple with data and total number of docs in matching the query in the database.
         """
         try:
-            response = self.session.get(url=url, verify=verify, params=params, timeout=timeout)
+            response = self.session.get(url=url, verify=verify, params=params, timeout=timeout, headers=self.headers)
         except requests.exceptions.ConnectTimeout:
             raise MPRestError(f"REST query timed out on URL {url}. Try again with a smaller request.")
 
@@ -845,7 +845,8 @@ class BaseRester(Generic[T]):
                 from mp_api.client.routes.materials import MaterialsRester
 
                 with MaterialsRester(
-                    api_key=self.api_key, endpoint=self.base_endpoint, use_document_model=False, monty_decode=False
+                    api_key=self.api_key, endpoint=self.base_endpoint, use_document_model=False, monty_decode=False,
+                    session=self.session, headers=self.headers
                 ) as mpr:
                     docs = mpr.search(task_ids=[document_id], fields=["material_id"])
 
